@@ -18,9 +18,13 @@ class AttrDict(dict):
                 value = AttrDict(value)
             return value
         except KeyError:
-            raise AttributeError(name)
+            # "from None" will remove the confusing KeyError from the stack trace
+            raise AttributeError(name) from None
 
     def __setattr__(self, name: str, value):
         # The default __getattr__ doesn't fail but also don't change values.
         cls = self.__class__.__name__
         raise NotImplementedError(f"{cls} does not support setting attributes")
+
+    def __dir__(self):
+        return self.keys()
